package controller

import (
	"fmt"
	"path/filepath"
	"strings"
	"time"

	"be.ems/src/framework/constants"
	"be.ems/src/framework/i18n"
	"be.ems/src/framework/reqctx"
	"be.ems/src/framework/resp"
	"be.ems/src/framework/telnet"
	"be.ems/src/framework/utils/file"
	"be.ems/src/framework/utils/parse"
	neService "be.ems/src/modules/ne/service"
	"be.ems/src/modules/ne_data/model"
	neDataService "be.ems/src/modules/ne_data/service"

	"github.com/gin-gonic/gin"
)

// 实例化控制层 UDMSubController 结构体
var NewUDMSub = &UDMSubController{
	udmSubService: neDataService.NewUDMSubUser,
	neInfoService: neService.NewNeInfo,
}

// UDM签约用户
//
// PATH /udm/sub
type UDMSubController struct {
	udmSubService *neDataService.UDMSubUser // UDM签约信息服务
	neInfoService *neService.NeInfo         // 网元信息服务
}

// UDM签约用户重载数据
//
// PUT /resetData/:neId
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId	path		string	true	"NE ID"	default(001)
//	@Success		200		{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Reload Data
//	@Description	UDM Subscriber User Reload Data
//	@Router			/neData/udm/sub/resetData/{neId} [put]
func (s *UDMSubController) ResetData(c *gin.Context) {
	neId := c.Param("neId")
	if neId == "" {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: neId is empty"))
		return
	}

	data := s.udmSubService.ResetData(neId)
	c.JSON(200, resp.OkData(data))
}

// UDM签约用户列表
//
// GET /list
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId		query		string	true	"NE ID"	default(001)
//	@Param			imsi		query		string	false	"IMSI"
//	@Param			msisdn		query		string	false	"Msisdn"
//	@Param			pageNum		query		number	true	"pageNum"	default(1)
//	@Param			pageSize	query		number	true	"pageSize"	default(10)
//	@Success		200			{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User List
//	@Description	UDM Subscriber User List
//	@Router			/neData/udm/sub/list [get]
func (s *UDMSubController) List(c *gin.Context) {
	query := reqctx.QueryMap(c)
	rows, total := s.udmSubService.FindByPage(query)
	c.JSON(200, resp.OkData(map[string]any{"rows": rows, "total": total}))
}

// UDM签约用户信息
//
// GET /:neId/:imsi
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId	path		string	true	"NE ID"	default(001)
//	@Param			value	path		string	true	"IMSI"
//	@Success		200		{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Information
//	@Description	UDM Subscriber User Information
//	@Router			/neData/udm/sub/{neId}/{value} [get]
func (s *UDMSubController) Info(c *gin.Context) {
	language := reqctx.AcceptLanguage(c)
	neId := c.Param("neId")
	imsi := c.Param("imsi")
	if neId == "" || imsi == "" {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: neId or imsi is empty"))
		return
	}

	// 查询网元获取IP
	neInfo := s.neInfoService.FindByNeTypeAndNeID("UDM", neId)
	if neInfo.NeId != neId || neInfo.IP == "" {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.noNEInfo")))
		return
	}
	// 网元主机的Telnet客户端
	telnetClient, err := s.neInfoService.NeRunTelnetClient("UDM", neId, 1)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}
	defer telnetClient.Close()

	// 发送MML
	cmd := fmt.Sprintf("dsp udmuser:imsi=%s", imsi)
	data, err := telnet.ConvertToMap(telnetClient, cmd)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}

	if len(data) == 0 {
		c.JSON(200, resp.ErrMsg("No Subs Data"))
		return
	}

	// 解析返回的数据
	u := s.udmSubService.ParseInfo(imsi, neId, data)
	s.udmSubService.Insert(neId, u)
	c.JSON(200, resp.OkData(u))
}

// UDM签约用户新增
//
// POST /:neId
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId	path		string	true	"NE ID"	default(001)
//	@Param			data	body		object	true	"Request Param"
//	@Success		200		{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Added
//	@Description	UDM Subscriber User Added
//	@Router			/neData/udm/sub/{neId} [post]
func (s *UDMSubController) Add(c *gin.Context) {
	language := reqctx.AcceptLanguage(c)
	neId := c.Param("neId")
	if neId == "" {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: neId is empty"))
		return
	}

	var body model.UDMSubUser
	if err := c.ShouldBindBodyWithJSON(&body); err != nil {
		errMsgs := fmt.Sprintf("bind err: %s", resp.FormatBindError(err))
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_PARSER, errMsgs))
		return
	}
	if len(body.IMSI) != 15 {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: IMSI length is not 15 bits"))
		return
	}

	// 查询网元获取IP
	neInfo := s.neInfoService.FindByNeTypeAndNeID("UDM", neId)
	if neInfo.NeId != neId || neInfo.IP == "" {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.noNEInfo")))
		return
	}
	// 网元主机的Telnet客户端
	telnetClient, err := s.neInfoService.NeRunTelnetClient("UDM", neId, 1)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}
	defer telnetClient.Close()

	// 发送MML
	cmd := fmt.Sprintf("add udmuser:imsi=%s,", body.IMSI)
	cmd += s.udmSubService.ParseCommandParams(body)
	data, err := telnet.ConvertToStr(telnetClient, cmd)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}

	// 命令ok时
	if strings.Contains(data, "ok") {
		body.NeId = neId
		s.udmSubService.Insert(neId, body)
	}
	c.JSON(200, resp.OkData(data))
}

// UDM签约用户批量新增
//
// POST /:neId/:num
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId	path		string	true	"NE ID"											default(001)
//	@Param			value	path		number	true	"Number of releases, value includes start imsi"	default(1)
//	@Param			data	body		object	true	"Request Param"
//	@Success		200		{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Batch Add
//	@Description	UDM Subscriber User Batch Add
//	@Router			/neData/udm/sub/{neId}/{value} [post]
func (s *UDMSubController) Adds(c *gin.Context) {
	language := reqctx.AcceptLanguage(c)
	neId := c.Param("neId")
	num := c.Param("num")
	if neId == "" || num == "" {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: neId/num is empty"))
		return
	}

	var body model.UDMSubUser
	if err := c.ShouldBindBodyWithJSON(&body); err != nil {
		errMsgs := fmt.Sprintf("bind err: %s", resp.FormatBindError(err))
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_PARSER, errMsgs))
		return
	}
	if len(body.IMSI) != 15 {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: IMSI length is not 15 bits"))
		return
	}

	// 查询网元获取IP
	neInfo := s.neInfoService.FindByNeTypeAndNeID("UDM", neId)
	if neInfo.NeId != neId || neInfo.IP == "" {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.noNEInfo")))
		return
	}
	// 网元主机的Telnet客户端
	telnetClient, err := s.neInfoService.NeRunTelnetClient("UDM", neId, 1)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}
	defer telnetClient.Close()

	// 发送MML
	cmd := fmt.Sprintf("baa udmuser:start_imsi=%s,start_msisdn=%s,sub_num=%s,", body.IMSI, body.MSISDN, num)
	cmd += s.udmSubService.ParseCommandParams(body)
	// 去除msisdn参数，避免重复
	omemsisdn := fmt.Sprintf(",msisdn=%s,", body.MSISDN)
	cmd = strings.Replace(cmd, omemsisdn, ",", 1)
	data, err := telnet.ConvertToStr(telnetClient, cmd)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}

	// 命令ok时
	if strings.Contains(data, "ok") {
		s.udmSubService.LoadData(neId, body.IMSI, num, body.Remark)
	}
	c.JSON(200, resp.OkData(data))
}

// UDM签约用户修改
//
// PUT /:neId
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId	path		string	true	"NE ID"	default(001)
//	@Param			data	body		object	true	"Request Param"
//	@Success		200		{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Modification
//	@Description	UDM Subscriber User Modification
//	@Router			/neData/udm/sub/{neId} [put]
func (s *UDMSubController) Edit(c *gin.Context) {
	language := reqctx.AcceptLanguage(c)
	neId := c.Param("neId")
	if neId == "" {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: neId is empty"))
		return
	}

	var body model.UDMSubUser
	if err := c.ShouldBindBodyWithJSON(&body); err != nil {
		errMsgs := fmt.Sprintf("bind err: %s", resp.FormatBindError(err))
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_PARSER, errMsgs))
		return
	}
	if len(body.IMSI) != 15 {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: IMSI length is not 15 bits"))
		return
	}

	// 查询网元获取IP
	neInfo := s.neInfoService.FindByNeTypeAndNeID("UDM", neId)
	if neInfo.NeId != neId || neInfo.IP == "" {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.noNEInfo")))
		return
	}
	// 网元主机的Telnet客户端
	telnetClient, err := s.neInfoService.NeRunTelnetClient("UDM", neId, 1)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}
	defer telnetClient.Close()

	// 发送MML
	cmd := fmt.Sprintf("mod udmuser:imsi=%s,", body.IMSI)
	cmd += s.udmSubService.ParseCommandParams(body)
	data, err := telnet.ConvertToStr(telnetClient, cmd)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}

	// 命令ok时
	if strings.Contains(data, "ok") {
		body.NeId = neId
		s.udmSubService.Insert(neId, body)
	}
	c.JSON(200, resp.OkData(data))
}

// UDM签约用户删除
//
// DELETE /:neId/:imsi
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId	path		string	true	"NE ID"	default(001)
//	@Param			value	path		string	true	"IMSI, multiple separated by a , sign"
//	@Success		200		{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Deletion
//	@Description	UDM Subscriber User Deletion
//	@Router			/neData/udm/sub/{neId}/{value} [delete]
func (s *UDMSubController) Remove(c *gin.Context) {
	language := reqctx.AcceptLanguage(c)
	neId := c.Param("neId")
	imsi := c.Param("imsi")
	if neId == "" || len(imsi) < 15 {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: neId/imsi is empty"))
		return
	}

	// 处理字符转id数组后去重
	imsiArr := strings.Split(imsi, ",")
	uniqueIDs := parse.RemoveDuplicates(imsiArr)
	if len(uniqueIDs) <= 0 {
		c.JSON(200, resp.Err(nil))
		return
	}

	// 查询网元获取IP
	neInfo := s.neInfoService.FindByNeTypeAndNeID("UDM", neId)
	if neInfo.NeId != neId || neInfo.IP == "" {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.noNEInfo")))
		return
	}
	// 网元主机的Telnet客户端
	telnetClient, err := s.neInfoService.NeRunTelnetClient("UDM", neId, 1)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}
	defer telnetClient.Close()

	resultData := map[string]string{}
	for _, imsi := range uniqueIDs {
		// 发送MML
		cmd := fmt.Sprintf("del udmuser:imsi=%s", imsi)
		data, err := telnet.ConvertToStr(telnetClient, cmd)
		if err != nil {
			resultData[imsi] = err.Error()
			continue
		}
		// 命令ok时
		if strings.Contains(data, "ok") {
			s.udmSubService.Delete(neId, imsi)
		}
		resultData[imsi] = data
	}

	c.JSON(200, resp.OkData(resultData))
}

// UDM签约用户批量删除
//
// DELETE /:neId/:imsi/:num
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId	path		string	true	"NE ID"	default(001)
//	@Param			imsi	path		string	true	"IMSI"
//	@Param			num		path		number	true	"Number of releases, value includes start imsi"
//	@Success		200		{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Batch Deletion
//	@Description	UDM Subscriber User Batch Deletion
//	@Router			/neData/udm/sub/{neId}/{imsi}/{num} [delete]
func (s *UDMSubController) Removes(c *gin.Context) {
	language := reqctx.AcceptLanguage(c)
	neId := c.Param("neId")
	imsi := c.Param("imsi")
	num := c.Param("num")
	if neId == "" || len(imsi) < 15 || num == "" {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: neId/imsi/num is empty"))
		return
	}

	// 查询网元获取IP
	neInfo := s.neInfoService.FindByNeTypeAndNeID("UDM", neId)
	if neInfo.NeId != neId || neInfo.IP == "" {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.noNEInfo")))
		return
	}
	// 网元主机的Telnet客户端
	telnetClient, err := s.neInfoService.NeRunTelnetClient("UDM", neId, 1)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}
	defer telnetClient.Close()

	// 发送MML
	cmd := fmt.Sprintf("bde udmuser:start_imsi=%s,sub_num=%s", imsi, num)
	data, err := telnet.ConvertToStr(telnetClient, cmd)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}

	// 命令ok时
	if strings.Contains(data, "ok") {
		s.udmSubService.LoadData(neId, imsi, num, "-(Deleted)-")
	}
	c.JSON(200, resp.OkData(data))
}

// UDM签约用户导出
//
// GET /export
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			neId		query		string	true	"NE ID"		default(001)
//	@Param			type		query		string	true	"File Type"	Enums(csv,txt)	default(txt)
//	@Param			imsi		query		string	false	"IMSI"
//	@Param			msisdn		query		string	false	"Msisdn"
//	@Param			pageNum		query		number	true	"pageNum"	default(1)
//	@Param			pageSize	query		number	true	"pageSize"	default(10)
//	@Success		200			{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Export
//	@Description	UDM Subscriber User Export
//	@Router			/neData/udm/sub/export [post]
func (s *UDMSubController) Export(c *gin.Context) {
	language := reqctx.AcceptLanguage(c)
	// 查询结果，根据查询条件结果，单页最大值限制
	neId := c.Query("neId")
	fileType := c.Query("type")
	if neId == "" || fileType == "" {
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_CHEACK, "bind err: neId or type is empty"))
		return
	}
	if !(fileType == "csv" || fileType == "txt") {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "ne.udm.errImportUserSubFileFormat")))
		return
	}

	query := reqctx.QueryMap(c)
	rows, total := s.udmSubService.FindByPage(query)
	if total == 0 {
		// 导出数据记录为空
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.exportEmpty")))
		return
	}

	// rows := s.udmSubService.SelectList(model.UDMSubUser{NeId: neId})
	if len(rows) <= 0 {
		// 导出数据记录为空
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.exportEmpty")))
		return
	}

	// 文件名
	fileName := fmt.Sprintf("udm_sub_user_export_%s_%d.%s", neId, time.Now().UnixMilli(), fileType)
	filePath := filepath.Join(file.ParseUploadFileDir(constants.UPLOAD_EXPORT), fileName)

	if fileType == "csv" {
		// 转换数据
		data := [][]string{}
		data = append(data, []string{"IMSI", "MSISDN", "UeAmbrTpl", "NssaiTpl", "AreaForbiddenTpl", "ServiceAreaRestrictionTpl", "RatRestrictions", "CnTypeRestrictions", "SmfSel", "SmData", "EPSDat", "CreateTime"})
		for _, v := range rows {
			epsDat := fmt.Sprintf("%s,%s,%s,%s,%s,%s,%s,%s", v.EpsFlag, v.EpsOdb, v.HplmnOdb, v.Ard, v.Epstpl, v.ContextId, v.ApnContext, v.StaticIp)
			createTime := ""
			if v.CreateTime == 0 {
				createTime = time.Now().Format(time.RFC3339)
			} else {
				createTime = time.UnixMilli(v.CreateTime).Format(time.RFC3339)
			}
			data = append(data, []string{v.IMSI, v.MSISDN, v.UeAmbrTpl, v.NssaiTpl, v.AreaForbiddenTpl, v.ServiceAreaRestrictionTpl, v.RatRestrictions, v.CnTypeRestrictions, v.SmfSel, v.SmData, epsDat, createTime})
		}
		// 输出到文件
		if err := file.WriterFileCSV(data, filePath); err != nil {
			c.JSON(200, resp.ErrMsg(err.Error()))
			return
		}
	}

	if fileType == "txt" {
		// 转换数据
		data := [][]string{}
		for _, v := range rows {
			epsDat := fmt.Sprintf("%s,%s,%s,%s,%s,%s,%s,%s", v.EpsFlag, v.EpsOdb, v.HplmnOdb, v.Ard, v.Epstpl, v.ContextId, v.ApnContext, v.StaticIp)
			createTime := ""
			if v.CreateTime == 0 {
				createTime = time.Now().Format(time.RFC3339)
			} else {
				createTime = time.UnixMilli(v.CreateTime).Format(time.RFC3339)
			}
			data = append(data, []string{v.IMSI, v.MSISDN, v.UeAmbrTpl, v.NssaiTpl, v.AreaForbiddenTpl, v.ServiceAreaRestrictionTpl, v.RatRestrictions, v.CnTypeRestrictions, v.SmfSel, v.SmData, epsDat, createTime})
		}
		// 输出到文件
		if err := file.WriterFileTXTLine(data, ",", filePath); err != nil {
			c.JSON(200, resp.ErrMsg(err.Error()))
			return
		}
	}

	c.FileAttachment(filePath, fileName)
}

// UDM签约用户导入
//
// POST /import
//
//	@Tags			ne_data/udm/sub
//	@Accept			json
//	@Produce		json
//	@Param			data	body		object	true	"Request Param"
//	@Success		200		{object}	object	"Response Results"
//	@Security		TokenAuth
//	@Summary		UDM Subscriber User Import
//	@Description	UDM Subscriber User Import
//	@Router			/neData/udm/sub/import [post]
func (s *UDMSubController) Import(c *gin.Context) {
	language := reqctx.AcceptLanguage(c)
	var body struct {
		NeId       string `json:"neId" binding:"required"`
		UploadPath string `json:"uploadPath" binding:"required"`
	}
	if err := c.ShouldBindBodyWithJSON(&body); err != nil {
		errMsgs := fmt.Sprintf("bind err: %s", resp.FormatBindError(err))
		c.JSON(422, resp.CodeMsg(resp.CODE_PARAM_PARSER, errMsgs))
		return
	}

	// 判断文件名
	if !(strings.HasSuffix(body.UploadPath, ".csv") || strings.HasSuffix(body.UploadPath, ".txt")) {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "ne.udm.errImportUserSubFileFormat")))
		return
	}

	// 查询网元获取IP
	neInfo := s.neInfoService.FindByNeTypeAndNeID("UDM", body.NeId)
	if neInfo.NeId != body.NeId || neInfo.IP == "" {
		c.JSON(200, resp.ErrMsg(i18n.TKey(language, "app.common.noNEInfo")))
		return
	}

	// 网元主机的SSH客户端
	// sshClient, err := s.neInfoService.NeRunSSHClient(neInfo.NeType, neInfo.NeId)
	// if err != nil {
	// 	c.JSON(200, resp.ErrMsg(err.Error()))
	// 	return
	// }
	// defer sshClient.Close()
	// // 网元主机的SSH客户端进行文件传输
	// sftpClient, err := sshClient.NewClientSFTP()
	// if err != nil {
	// 	c.JSON(200, resp.ErrMsg(err.Error()))
	// 	return
	// }
	// defer sftpClient.Close()

	// 本地文件
	localFilePath := file.ParseUploadFileAbsPath(body.UploadPath)
	neFilePath := fmt.Sprintf("/tmp/%s", filepath.Base(localFilePath))
	// 复制到远程
	// if err = sftpClient.CopyFileLocalToRemote(localFilePath, neFilePath); err != nil {
	// 	c.JSON(200, resp.ErrMsg("error uploading file"))
	// 	return
	// }
	if err := file.CopyFile(localFilePath, neFilePath); err != nil {
		c.JSON(200, resp.ErrMsg("error uploading file"))
		return
	}

	// 网元主机的Telnet客户端
	telnetClient, err := s.neInfoService.NeRunTelnetClient(neInfo.NeType, neInfo.NeId, 1)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}
	defer telnetClient.Close()

	// 发送MML
	cmd := fmt.Sprintf("import udmuser:path=%s", neFilePath)
	data, err := telnet.ConvertToStr(telnetClient, cmd)
	if err != nil {
		c.JSON(200, resp.ErrMsg(err.Error()))
		return
	}

	// 命令ok时
	if strings.Contains(data, "ok") {
		if strings.HasSuffix(body.UploadPath, ".csv") {
			data := file.ReadFileCSV(localFilePath)
			go s.udmSubService.InsertData(neInfo.NeId, "csv", data)
		}
		if strings.HasSuffix(body.UploadPath, ".txt") {
			data := file.ReadFileTXTLine(",", localFilePath)
			go s.udmSubService.InsertData(neInfo.NeId, "txt", data)
		}
	}
	c.JSON(200, resp.OkMsg(data))
}
